'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var pluginScaffolderBackend = require('@backstage/plugin-scaffolder-backend');
var clientNode = require('@kubernetes/client-node');
var yaml = require('js-yaml');

function _interopNamespace(e) {
	if (e && e.__esModule) return e;
	var n = Object.create(null);
	if (e) {
		Object.keys(e).forEach(function (k) {
			if (k !== 'default') {
				var d = Object.getOwnPropertyDescriptor(e, k);
				Object.defineProperty(n, k, d.get ? d : {
					enumerable: true,
					get: function () { return e[k]; }
				});
			}
		});
	}
	n["default"] = e;
	return Object.freeze(n);
}

var yaml__namespace = /*#__PURE__*/_interopNamespace(yaml);

const deployKubernetesAction = () => {
  return pluginScaffolderBackend.createTemplateAction({
    id: "deploy:kubernetes",
    description: "Applies a Kubernetes manifest",
    schema: {
      input: {
        type: "object",
        properties: {
          manifest: {
            title: "Kubernetes Manifest",
            description: "YAML or JSON manifest for the Kubernetes resource to be applied",
            type: "any"
          },
          clusterUrl: {
            title: "Cluster URL",
            description: "URL of the Kubernetes API",
            type: "string"
          },
          authToken: {
            title: "Token",
            description: "Bearer token to authenticate with the Kubernetes API",
            type: "string"
          }
        },
        required: ["manifest", "clusterUrl", "authToken"]
      }
    },
    async handler(ctx) {
      var _a, _b;
      const manifest = ctx.input.manifest;
      const clusterUrl = ctx.input.clusterUrl;
      const token = ctx.input.authToken;
      console.log(
        `Type of content: ${typeof manifest}, Content preview: ${manifest}`
      );
      const kubeConfig = new clientNode.KubeConfig();
      kubeConfig.loadFromOptions({
        clusters: [
          {
            name: "dynamic-cluster",
            server: clusterUrl,
            skipTLSVerify: true
          }
        ],
        users: [
          {
            name: "dynamic-user",
            token
          }
        ],
        contexts: [
          {
            name: "dynamic-context",
            user: "dynamic-user",
            cluster: "dynamic-cluster"
          }
        ],
        currentContext: "dynamic-context"
      });
      const api = kubeConfig.makeApiClient(clientNode.KubernetesObjectApi);
      const resources = yaml__namespace.loadAll(manifest);
      if (!resources || !Array.isArray(resources) || resources.length === 0) {
        throw new Error(
          "Invalid manifest: must contain at least one valid YAML or JSON object"
        );
      }
      for (const resource of resources) {
        try {
          const result = await api.create(resource);
          ctx.logger.info(
            `Successfully applied manifest for ${resource.kind}/${(_a = resource.metadata) == null ? void 0 : _a.name}: ${result}`
          );
        } catch (error) {
          ctx.logger.error(
            `Failed to apply Kubernetes manifest for ${resource.kind}/${(_b = resource.metadata) == null ? void 0 : _b.name}: ${error}`
          );
        }
      }
    }
  });
};

exports.deployKubernetesAction = deployKubernetesAction;
//# sourceMappingURL=index.cjs.js.map
